/*
 * Calc_Address_Font_UTF16_16x16.c
 *
 *  Created on: 2024/11/18
 *      Author: egaono-electronics
 */

#include "Calc_Address_Font_UTF16_16x16.h"



//----------------------------------------------------------
// UTF-8 を UTF-16 に変換する。
//----------------------------------------------------------
// 引数;
// uint16_t uint16_Length : 変換後の UTF-16 コードの文字数
// uint8_t *puint8_UTF8 :
//                  UTF-8コードが格納されたBufferのポインタ

// uint8_t *puint8_Work : 処理用Work
// uint16_t *puint16_UTF16 :
//          変換後の UTF-16コードを格納するBufferのポインタ

// 戻り値;
//    0 : OK
//    1 : NG
//----------------------------------------------------------
int16_t Convert_UTF8_to_UTF16(uint16_t uint16_Length,
                             uint8_t *puint8_UTF8,
                             uint8_t *puint8_Work,
                             uint16_t *puint16_UTF16)
{
  uint16_t uint16_Position;
  uint16_t uint16_Count;


  uint16_Position = 0;
  uint16_Count = 0;

  do{
    if((puint8_UTF8[uint16_Position] & 0x80) == 0){
      // U+007Fまでのコード
      puint16_UTF16[uint16_Count]
            = (uint16_t)puint8_UTF8[uint16_Position];
      uint16_Position++;
      uint16_Count++;
    }
    else if((puint8_UTF8[uint16_Position] & 0xE0) == 0xC0){
      // U+07FFまでのコード
      puint16_UTF16[uint16_Count]
            = (uint16_t)(puint8_UTF8[uint16_Position] & 0x1F);
      puint16_UTF16[uint16_Count] <<= 6;
      uint16_Position++;

      puint16_UTF16[uint16_Count]
            |= (uint16_t)(puint8_UTF8[uint16_Position] & 0x3F);
      uint16_Position++;
      uint16_Count++;
    }
    else if((puint8_UTF8[uint16_Position] & 0xF0) == 0xE0){
      // U+FFFFまでのコード
      puint16_UTF16[uint16_Count]
            = (uint16_t)(puint8_UTF8[uint16_Position] & 0x0F);
      puint16_UTF16[uint16_Count] <<= 12;
      uint16_Position++;

      puint16_UTF16[uint16_Count]
        |= ((uint16_t)(puint8_UTF8[uint16_Position] & 0x3F))
            << 6;
      uint16_Position++;

      puint16_UTF16[uint16_Count]
            |= (uint16_t)(puint8_UTF8[uint16_Position] & 0x3F);
      uint16_Position++;
      uint16_Count++;
    }
    else{
      return(1);  // NG
    }
  }while(uint16_Count < uint16_Length);


  return(0);  // OK
}



//----------------------------------------------------------
// Font Address算出 : UTF-16
//----------------------------------------------------------
// 引数;
// uint16_t uint16_UTF16 : UTF-16 文字コード

// 戻り値; フォント格納アドレス
//----------------------------------------------------------
uint32_t Calc_Address_Font_UTF16_16x16(
                                    uint16_t uint16_UTF16)
{
  uint32_t uint32_StartAddress = 0;
  uint32_t uint32_Offset = 0;
  uint32_t uint32_AddressFont = 0;


  if(uint16_UTF16 < 0x0020){
    return(0);  // NG
  }


  // フォント配列の容量を小さくするために、
  // 使用しない文字コードのフォントは記述していないので、
  // アドレスが詰まっている。

  // そのため、文字コードの範囲ごとの開始アドレスと
  // 文字コードのオフセットを算出している。
  if((uint16_UTF16 >= 0x0020) && (uint16_UTF16 <= 0x007F)){
    uint32_StartAddress = 0x00000000;
    uint32_Offset = uint16_UTF16 - 0x0020;
  }
  else if((uint16_UTF16 >= 0x00A0) && (uint16_UTF16 <= 0x00FF)){
    uint32_StartAddress = 0x00000C00;
    uint32_Offset = uint16_UTF16 - 0x00A0;
  }
  else if((uint16_UTF16 >= 0x2010) && (uint16_UTF16 <= 0x2312)){
    uint32_StartAddress = 0x00001800;
    uint32_Offset = uint16_UTF16 - 0x2010;
  }
  else if((uint16_UTF16 >= 0x2460) && (uint16_UTF16 <= 0x2473)){
    uint32_StartAddress = 0x00007860;
    uint32_Offset = uint16_UTF16 - 0x2460;
  }
  else if((uint16_UTF16 >= 0x2500) && (uint16_UTF16 <= 0x254B)){
    uint32_StartAddress = 0x00007AE0;
    uint32_Offset = uint16_UTF16 - 0x2500;
  }
  else if((uint16_UTF16 >= 0x25A0) && (uint16_UTF16 <= 0x266F)){
    uint32_StartAddress = 0x00008460;
    uint32_Offset = uint16_UTF16 - 0x25A0;
  }
  else if((uint16_UTF16 >= 0x3000) && (uint16_UTF16 <= 0x301F)){
    uint32_StartAddress = 0x00009E60;
    uint32_Offset = uint16_UTF16 - 0x3000;
  }
  else if((uint16_UTF16 >= 0x3040) && (uint16_UTF16 <= 0x30FF)){
    uint32_StartAddress = 0x0000A260;
    uint32_Offset = uint16_UTF16 - 0x3040;
  }
  else if((uint16_UTF16 >= 0x3230) && (uint16_UTF16 <= 0x33FF)){
    uint32_StartAddress = 0x0000BA60;
    uint32_Offset = uint16_UTF16 - 0x3230;
  }
  else if((uint16_UTF16 >= 0x4E00) && (uint16_UTF16 <= 0x9FD5)){
    uint32_StartAddress = 0x0000F460;
    uint32_Offset = uint16_UTF16 - 0x4E00;
  }
  else if((uint16_UTF16 >= 0xF900) && (uint16_UTF16 <= 0xFA6D)){
    uint32_StartAddress = 0x000B2F20;
    uint32_Offset = uint16_UTF16 - 0xF900;
  }
  else if((uint16_UTF16 >= 0xFF00) && (uint16_UTF16 <= 0xFFEE)){
    uint32_StartAddress = 0x000B5CE0;
    uint32_Offset = uint16_UTF16 - 0xFF00;
  }
  else{
    return(0);  // NG
  }

  // 上記で設定された開始アドレスとオフセットから
  // フォント配列の位置を算出する。
  uint32_AddressFont = uint32_StartAddress + uint32_Offset * 32;


  return(uint32_AddressFont);
}
